HbNav class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
back({int count = 1, Object? arguments})
→ void
-
back to the previous page
无context返回,并指定路由返回多少层,默认返回上一页面, 返回带参数params
-
pop({int count = 1, Object? arguments})
→ void
-
关闭弹窗
-
push(String path, {Object? arguments, TransitionType transitionType = TransitionType.fromRight})
→ Future
-
push page
Navigates to a new route in the application.
-
replease(String path, {Object? arguments, TransitionType transitionType = TransitionType.fromRight})
→ Future
-
replace page
Replaces the current route with a new one.
-
switchTab(String path, {Object? arguments, TransitionType transitionType = TransitionType.none})
→ Future
-
Navigate to a page and clear the router stack
清空路由栈跳转,一般用于跳转首页这种情况