HbRouter class

Constructors

HbRouter(Map<String, HbWidgetBuilder> routes, {HbMiddleware? middleware})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
middleware HbMiddleware?
final
routes Map<String, HbWidgetBuilder>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateRoute(RouteSettings settings) Route?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentRoute HbCurrentRoute?
no setter
history List<HbCurrentRoute>
getter/setter pair
key GlobalKey<NavigatorState>
final